
# Wiener Linien departure times (Vienna Public Transport)
This module displays departure time from a specific stop.

To identify the stopId please use this service:

https://till.mabe.at/rbl/


## Usage
```
define wl_U1_departures fhempy wienerlinien 4118
```